@@ -107,11 +107,14 @@ class Insight_Definition:
         r = self.__make_put_request(url, body)
         self.components = r.json()["components"]
 
-    def add_widget(self, widget_type: str, query_ids:list=[], settings:dict={}, values:dict={}, texts:dict={}, charts:list=[]):
+    def add_widget(self, widget_type: str, query_ids:list=[], settings:dict={}, values:dict={}, texts:dict={}, charts:list=[], multiple= False):
         position = (len(self.components))
         widget_id = self.__create_widget(position, widget_type)
         if(query_ids!=[]):
-            self.edit_widget(widget_id, widget_type,query_ids, settings, values, texts, charts)
+            if(multiple):
+                self.edit_widget_multiple(widget_id, widget_type, query_ids, settings, values, texts, charts)
+            else:
+                self.edit_widget(widget_id, widget_type,query_ids, settings, values, texts, charts)
         return widget_id
 
     def edit_widget(self, widget_id, widget_type: str, query_ids:list, field_codes:dict, values:dict={}, texts:dict={}, charts:list=[]):
@@ -177,7 +180,7 @@ class Insight_Definition:
             self.edit_widget_test(widget_id, widget_type,query_ids, settings, values, texts, charts)
         return widget_id
 
-    def edit_widget_test(self, widget_id, widget_type: str, query_ids:list, field_codes:dict, values:dict={}, texts:dict={}, charts:list=[]):
+    def edit_widget_multiple(self, widget_id, widget_type: str, query_ids:list, field_codes:dict, values:dict={}, texts:dict={}, charts:list=[]):
 
         url = self.smart_insight_url+"/definitions/"+self.definition_id+"/widgets/"+widget_id
         columns = []
@@ -202,7 +205,6 @@ class Insight_Definition:
         for field in field_codes.keys():
             ids = []
             for column in columns:
-
                 if(column["code"] in field_codes[field] or column["name"] in field_codes[field]):
                     for query in query_ids:
                         if(str(field_codes[field]).startswith(query)):
@@ -212,7 +214,11 @@ class Insight_Definition:
                                continue
                         else:
                             ids.append(column["id"])
-            settings[field + "_id"] = ids
+
+            if(len(ids>1)):
+                settings[field + "_id"] = ids
+            else:
+                settings[field + "_id"] = ids[0]
 
         for key in values.keys():
             settings[key + "_id"] = values[key]
